Area chart builder — like line chart but with filled regions under each series.
Structs
- Area
Chart Config - Configuration for area chart rendering.
Functions
- build
- Build area chart primitives from series data.
Area chart builder — like line chart but with filled regions under each series.