render

Function render 

pub fn render(document: &Document) -> Result<Vec<u8>, FormeError>
Render a document to PDF bytes.

This is the primary entry point. Takes a document tree and returns the raw bytes of a valid PDF file. If the document has a signature configuration, the output PDF is digitally signed.