render_with_layout

Function render_with_layout 

pub fn render_with_layout(
    document: &Document,
) -> Result<(Vec<u8>, LayoutInfo), FormeError>
Render a document to PDF bytes along with layout metadata.

Same as render() but also returns LayoutInfo describing the position and dimensions of every element on every page. If the document has a certification configuration, the output PDF is digitally signed.