Module fallback

Module fallback 

Per-Character Font Fallback

Segments text into runs by font coverage. When a font family is a comma-separated chain like “Inter, NotoSansArabic, NotoSansSC”, each character is resolved to the first font that has a glyph for it. Consecutive characters using the same font are coalesced into runs to minimize shaping calls.

Structs

FontRun
A contiguous run of characters that all resolve to the same font.

Functions

segment_by_font
Segment characters into runs by font coverage.