pub enum BreakDecision {
Place,
MoveToNextPage,
Split {
items_on_current_page: usize,
},
}Expand description
Decide what to do when a node doesn’t fit on the current page.
Variants
Place
Place the entire node on the current page (it fits).
MoveToNextPage
Move the entire node to the next page (unbreakable, or better aesthetics).
Split
Split the node: place some content here, continue on the next page.