pub fn shaped_width(
glyphs: &[ShapedGlyph],
units_per_em: u16,
font_size: f64,
) -> f64Expand description
Compute the total advance width of shaped glyphs in points.
pub fn shaped_width(
glyphs: &[ShapedGlyph],
units_per_em: u16,
font_size: f64,
) -> f64Compute the total advance width of shaped glyphs in points.